pub struct UnsupervisedHttpServer<S> { /* private fields */ }Expand description
An HTTP server that spawns and manages itself.
Deprecated
Callers should generally prefer to use HttpServer, as it is designed to run under supervision and play nicely
with supervision trees: graceful shutdown, spawning of connection handlers in the right place, etc.
Implementations
Sourceimpl<S> UnsupervisedHttpServer<S>
impl<S> UnsupervisedHttpServer<S>
Sourcepub fn from_listener(listener: ConnectionOrientedListener, service: S) -> Self
pub fn from_listener(listener: ConnectionOrientedListener, service: S) -> Self
Creates a new UnsupervisedHttpServer from the given listener and service.
Panics
This will panic if called outside the context of a Tokio runtime.
Sourcepub fn with_tls_config(self, config: ServerConfig) -> Self
pub fn with_tls_config(self, config: ServerConfig) -> Self
Sets the TLS configuration for the server.
This will enable TLS for the server, and the server will only accept connections that are encrypted with TLS.
Defaults to TLS being disabled.
Sourcepub fn with_executor(self, executor: Handle) -> Self
pub fn with_executor(self, executor: Handle) -> Self
Sets the executor for the server.
This executor will be used for spawning tasks to handle incoming connections, but not for the spawn that accepts new connections.
Defaults to the current Tokio runtime at the time from_listener is called.
Sourceimpl<S, B> UnsupervisedHttpServer<S>
impl<S, B> UnsupervisedHttpServer<S>
Sourcepub fn listen(self) -> (ShutdownCoordinator, ErrorHandle)
pub fn listen(self) -> (ShutdownCoordinator, ErrorHandle)
Starts the server and listens for incoming connections.
Returns two handles: one for shutting down the server, and one for receiving any errors that occur while the server is running.