pub struct HttpServer<S> { /* private fields */ }Expand description
An HTTP server.
Serves a single Service over a connection-oriented listener, optionally with TLS. The server can’t be run
directly: it is only usable by adding it to a supervisor.
Supervision
The listen address is bound during initialization, so a failure to bind is raised before the supervised worker starts running, and a restart rebinds.
The server will attempt to gracefully shutdown existing connections when the parent supervisor signals shutdown. This will cause the worker to utilize the maximum allowable grace period during shutdown: it will attempt to take as long as necessary to gracefully shutdown existing connections, bounded only by the parent supervisor.
Implementations
Sourceimpl<S> HttpServer<S>
impl<S> HttpServer<S>
Sourcepub fn from_listen_address(listen_address: ListenAddress, service: S) -> Self
pub fn from_listen_address(listen_address: ListenAddress, service: S) -> Self
Creates a server that will listen on the given address.
Sourcepub fn with_graceful_shutdown_timeout(self, timeout: Duration) -> Self
pub fn with_graceful_shutdown_timeout(self, timeout: Duration) -> Self
Sets the graceful shutdown timeout for this server.
During shutdown, the server will for all in-flight connections to complete before ultimately completing itself. When no timeout is specified, this will lead to the worker taking the maximum allowable time to shutdown if connections are blocked or otherwise “stuck.” Setting an explicit graceful shutdown timeout will cause the worker to bound how long it waits for in-flight connections to shutdown before forcefully completing and moving on.
Defaults to no timeout (wait as long as allowed).
Sourcepub fn with_tls_config(self, config: ServerConfig) -> Self
pub fn with_tls_config(self, config: ServerConfig) -> Self
Sets the TLS configuration for the server.
This enables TLS, after which the server only accepts connections that are encrypted with TLS.
Defaults to TLS being disabled.